@@ -12,9 +12,9 @@
 
 namespace NMix{
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+//#ifdef __cplusplus
+//extern "C" {
+//#endif
 
 /***** ***************************************************************************************** *****/
 /***** NMix::Pr_y_and_cum_Pr_y                                                                   *****/
@@ -178,9 +178,9 @@ Pr_y_and_cum_Pr_y(double* Pr_y,
   return;
 }
 
-#ifdef __cplusplus
-}
-#endif
+//#ifdef __cplusplus
+//}
+//#endif
 
 }  // end of namespace NMix
 
